@@ -3,16 +3,13 @@ import setuptools
 with open("README_Argpass.md", "r") as fh:
     long_description = fh.read()
 
-#with open("README_Log.md", "r") as fh:
-#    long_description_log = fh.read()
-
 setuptools.setup(
     name="pcs_argpass",
-    version="0.8.12",
+    version="0.8.14",
     python_requires='>=3.6',
     author="Rainer Pietsch",
     author_email="r.pietsch@pcs-at.com",
-    description="Argument parser and checker. Generic logger",
+    description="Argument parser and checker.",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://github.com/rpietsch1953/pcs-pylibs",
